@@ -9,7 +9,7 @@ from google.protobuf.json_format import MessageToJson
 import pprint
 
 import graphsignal
-from graphsignal.proto import profiles_pb2
+from graphsignal.proto import signals_pb2
 from graphsignal.uploader import Uploader
 
 logger = logging.getLogger('graphsignal')
@@ -21,14 +21,12 @@ class JaxProfilerTest(unittest.TestCase):
             logger.addHandler(logging.StreamHandler(sys.stdout))
         graphsignal.configure(
             api_key='k1',
-            workload_name='w1',
             debug_mode=True)
 
     def tearDown(self):
         graphsignal.shutdown()
 
-    @patch.object(Uploader, 'upload_profile')
-    def test_profile_inference(self, mocked_upload_profile):
+    def test_read_info(self):
         try:
             import jax
             import jax.numpy as jnp
@@ -38,30 +36,45 @@ class JaxProfilerTest(unittest.TestCase):
             logger.info('Not testing JAX profiler, package not found.')
             return
 
-        from graphsignal.profilers.jax import profile_inference
+        from graphsignal.profilers.jax import JaxProfiler
 
-        with profile_inference():
-            key = random.PRNGKey(0)
-            x = random.normal(key, (10,))
-            size = 100
-            x = random.normal(key, (size, size), dtype=jnp.float32)
-            jnp.dot(x, x.T).block_until_ready()
-
-        graphsignal.upload()
-        profile = mocked_upload_profile.call_args[0][0]
-
-        #pp = pprint.PrettyPrinter()
-        #pp.pprint(MessageToJson(profile))
+        profiler = JaxProfiler()
+        signal = signals_pb2.MLSignal()
+        profiler.read_info(signal)
 
         self.assertEqual(
-            profile.frameworks[0].type,
-            profiles_pb2.FrameworkInfo.FrameworkType.JAX_FRAMEWORK)
+            signal.frameworks[0].type,
+            signals_pb2.FrameworkInfo.FrameworkType.JAX_FRAMEWORK)
 
-        self.assertEqual(profile.inference_stats.inference_count, 1)
-        self.assertTrue(profile.inference_stats.total_time_us > 0)
+    def test_start_stop(self):
+        try:
+            import jax
+            import jax.numpy as jnp
+            from jax import grad, jit, vmap
+            from jax import random
+        except ImportError:
+            logger.info('Not testing JAX profiler, package not found.')
+            return
+
+        from graphsignal.profilers.jax import JaxProfiler
+
+        profiler = JaxProfiler()
+        signal = signals_pb2.MLSignal()
+        profiler.start(signal)
+
+        key = random.PRNGKey(0)
+        x = random.normal(key, (10,))
+        size = 100
+        x = random.normal(key, (size, size), dtype=jnp.float32)
+        jnp.dot(x, x.T).block_until_ready()
+
+        profiler.stop(signal)
+
+        #pp = pprint.PrettyPrinter()
+        #pp.pprint(MessageToJson(signal))
 
         test_op_stats = None
-        for op_stats in profile.op_stats:
+        for op_stats in signal.op_stats:
             if op_stats.op_name == 'Thunk':
                 test_op_stats = op_stats
                 break
@@ -74,4 +87,4 @@ class JaxProfilerTest(unittest.TestCase):
             self.assertTrue(test_op_stats.total_host_time_us >= 1)
             self.assertTrue(test_op_stats.self_host_time_us >= 1)
 
-        self.assertNotEqual(profile.trace_data, b'')
+        self.assertNotEqual(signal.trace_data, b'')
