@@ -7,8 +7,8 @@ from google.protobuf.json_format import MessageToJson
 import pprint
 
 import graphsignal
-from graphsignal.profilers.pytorch import profile_inference
-from graphsignal.proto import profiles_pb2
+from graphsignal.profilers.pytorch import PyTorchProfiler
+from graphsignal.proto import signals_pb2
 from graphsignal.uploader import Uploader
 
 logger = logging.getLogger('graphsignal')
@@ -20,7 +20,6 @@ class PyTorchProfilerTest(unittest.TestCase):
             logger.addHandler(logging.StreamHandler(sys.stdout))
         graphsignal.configure(
             api_key='k1',
-            workload_name='w1',
             debug_mode=True)
 
     def tearDown(self):
@@ -28,8 +27,16 @@ class PyTorchProfilerTest(unittest.TestCase):
             torch.cuda.empty_cache()
         graphsignal.shutdown()
 
-    @patch.object(Uploader, 'upload_profile')
-    def test_profile_inference(self, mocked_upload_profile):
+    def test_read_info(self):
+        profiler = PyTorchProfiler()
+        signal = signals_pb2.MLSignal()
+        profiler.read_info(signal)
+
+        self.assertEqual(
+            signal.frameworks[0].type,
+            signals_pb2.FrameworkInfo.FrameworkType.PYTORCH_FRAMEWORK)
+
+    def test_start_stop(self):
         x = torch.arange(-5, 5, 0.1).view(-1, 1)
         y = -5 * x + 0.1 * torch.randn(x.size())
         model = torch.nn.Linear(1, 1)
@@ -38,25 +45,17 @@ class PyTorchProfilerTest(unittest.TestCase):
             y = y.to('cuda:0')
             model = model.to('cuda:0')
 
-        with profile_inference(batch_size=128):
-            y1 = model(x)
-
-        graphsignal.upload()
-        profile = mocked_upload_profile.call_args[0][0]
+        profiler = PyTorchProfiler()
+        signal = signals_pb2.MLSignal()
+        profiler.start(signal)
+        y1 = model(x)
+        profiler.stop(signal)
 
         #pp = pprint.PrettyPrinter()
-        #pp.pprint(MessageToJson(profile))
-
-        self.assertEqual(
-            profile.frameworks[0].type,
-            profiles_pb2.FrameworkInfo.FrameworkType.PYTORCH_FRAMEWORK)
-
-        self.assertEqual(profile.inference_stats.inference_count, 1)
-        self.assertTrue(profile.inference_stats.total_time_us > 0)
-        self.assertEqual(profile.inference_stats.sample_count, 128)
+        #pp.pprint(MessageToJson(signal))
 
         test_op_stats = None
-        for op_stats in profile.op_stats:
+        for op_stats in signal.op_stats:
             if op_stats.op_name == 'aten::addmm':
                 test_op_stats = op_stats
                 break
@@ -69,4 +68,4 @@ class PyTorchProfilerTest(unittest.TestCase):
             self.assertTrue(test_op_stats.total_host_time_us >= 1)
             self.assertTrue(test_op_stats.self_host_time_us >= 1)
 
-        self.assertNotEqual(profile.trace_data, b'')
+        self.assertNotEqual(signal.trace_data, b'')
