@@ -8,29 +8,22 @@ import tensorflow as tf
 
 import graphsignal
 from graphsignal.proto_utils import parse_semver, compare_semver
-from graphsignal.proto import profiles_pb2
-from graphsignal.inference_span import InferenceSpan
+from graphsignal.proto import signals_pb2
 from graphsignal.profilers.operation_profiler import OperationProfiler
 from graphsignal.profilers.profiler_utils import create_log_dir, remove_log_dir, convert_tensorflow_profile
 
 logger = logging.getLogger('graphsignal')
 
-class TensorflowProfiler(OperationProfiler):
+class TensorFlowProfiler(OperationProfiler):
     def __init__(self):
-        self._is_initialized = False
         self._log_dir = None
         self._tensorflow_version = None
         self._global_rank = None
         self._world_size = None
 
-    def start(self, profile, context):
-        logger.debug('Activating TensorFlow profiler')
-
-        # Initialization
-        if not self._is_initialized:
-            self._is_initialized = True
-
-            self._tensorflow_version = profiles_pb2.SemVer()
+    def read_info(self, signal):
+        if not self._tensorflow_version:
+            self._tensorflow_version = signals_pb2.SemVer()
             parse_semver(self._tensorflow_version, tf.__version__)
             if compare_semver(self._tensorflow_version, (2, 2, 0)) == -1:
                 raise Exception(
@@ -48,23 +41,24 @@ class TensorflowProfiler(OperationProfiler):
                 except:
                     logger.warning('Error parsing TF_CONFIG', exc_info=True)
 
-        # Profiler info
-        profile.profiler_info.operation_profiler_type = profiles_pb2.ProfilerInfo.ProfilerType.TENSORFLOW_PROFILER
-
         # Framework info
-        framework = profile.frameworks.add()
-        framework.type = profiles_pb2.FrameworkInfo.FrameworkType.TENSORFLOW_FRAMEWORK
+        framework = signal.frameworks.add()
+        framework.type = signals_pb2.FrameworkInfo.FrameworkType.TENSORFLOW_FRAMEWORK
         framework.version.CopyFrom(self._tensorflow_version)
 
         # Process info
         if self._global_rank is not None and self._global_rank >= 0:
-            if graphsignal._agent.global_rank == -1:
-                profile.process_usage.global_rank = self._global_rank
+            signal.process_usage.global_rank = self._global_rank
 
-        # Step stats
+        # Cluster stats
         if self._world_size is not None and self._world_size > 0:
-            profile.inference_stats.world_size = self._world_size
-            graphsignal.log_parameter('world_size', self._world_size)
+            signal.cluster_info.world_size = self._world_size
+
+    def start(self, signal):
+        logger.debug('Activating TensorFlow profiler')
+
+        # Profiler info
+        signal.agent_info.operation_profiler_type = signals_pb2.AgentInfo.ProfilerType.TENSORFLOW_PROFILER
 
         try:
             self._log_dir = create_log_dir()
@@ -78,27 +72,12 @@ class TensorflowProfiler(OperationProfiler):
             remove_log_dir(self._log_dir)
             raise e
 
-    def stop(self, profile, context):
+    def stop(self, signal):
         logger.debug('Deactivating TensorFlow profiler')
 
         try:
             tf.profiler.experimental.stop()
 
-            convert_tensorflow_profile(self._log_dir, profile)
-        except Exception as e:
-            raise e
+            convert_tensorflow_profile(self._log_dir, signal)
         finally:
            remove_log_dir(self._log_dir)
-
-
-_profiler = TensorflowProfiler()
-
-def profile_inference(
-        batch_size: Optional[int] = None,
-        ensure_profile: Optional[bool] = False) -> InferenceSpan:
-    graphsignal._check_configured()
-
-    return InferenceSpan(
-        batch_size=batch_size,
-        ensure_profile=ensure_profile,
-        operation_profiler=_profiler)
