@@ -9,27 +9,25 @@ from google.protobuf.json_format import MessageToJson
 import pprint
 
 import graphsignal
-from graphsignal.profilers.tensorflow import profile_inference
-from graphsignal.proto import profiles_pb2
+from graphsignal.profilers.tensorflow import TensorFlowProfiler
+from graphsignal.proto import signals_pb2
 from graphsignal.uploader import Uploader
 
 logger = logging.getLogger('graphsignal')
 
 
-class TensorflowProfilerTest(unittest.TestCase):
+class TensorFlowProfilerTest(unittest.TestCase):
     def setUp(self):
         if len(logger.handlers) == 0:
             logger.addHandler(logging.StreamHandler(sys.stdout))
         graphsignal.configure(
             api_key='k1',
-            workload_name='w1',
             debug_mode=True)
 
     def tearDown(self):
         graphsignal.shutdown()
 
-    @patch.object(Uploader, 'upload_profile')
-    def test_profile_inference(self, mocked_upload_profile):
+    def test_read_info(self):
         os.environ["TF_CONFIG"] = json.dumps({
             "cluster": {
                 "chief": ["host1:port"],
@@ -38,6 +36,18 @@ class TensorflowProfilerTest(unittest.TestCase):
             "task": {"type": "worker", "index": 1}
         })
 
+        profiler = TensorFlowProfiler()
+        signal = signals_pb2.MLSignal()
+        profiler.read_info(signal)
+
+        self.assertEqual(
+            signal.frameworks[0].type,
+            signals_pb2.FrameworkInfo.FrameworkType.TENSORFLOW_FRAMEWORK)
+        self.assertEqual(signal.process_usage.global_rank, 1)
+
+        self.assertEqual(signal.cluster_info.world_size, 3)
+
+    def test_start_stop(self):
         @tf.function
         def f(x):
             while tf.reduce_sum(x) > 1:
@@ -45,27 +55,17 @@ class TensorflowProfilerTest(unittest.TestCase):
                 x = tf.tanh(x)
             return x
 
-        with profile_inference(batch_size=128):
-            f(tf.random.uniform([5]))
-
-        graphsignal.upload()
-        profile = mocked_upload_profile.call_args[0][0]
+        profiler = TensorFlowProfiler()
+        signal = signals_pb2.MLSignal()
+        profiler.start(signal)
+        f(tf.random.uniform([5]))
+        profiler.stop(signal)
 
         #pp = pprint.PrettyPrinter()
-        #pp.pprint(MessageToJson(profile))
-
-        self.assertEqual(
-            profile.frameworks[0].type,
-            profiles_pb2.FrameworkInfo.FrameworkType.TENSORFLOW_FRAMEWORK)
-        self.assertEqual(profile.process_usage.global_rank, 1)
-
-        self.assertEqual(profile.inference_stats.inference_count, 1)
-        self.assertTrue(profile.inference_stats.total_time_us > 0)
-        self.assertEqual(profile.inference_stats.sample_count, 128)
-        self.assertEqual(profile.inference_stats.world_size, 3)
+        #pp.pprint(MessageToJson(signal))
 
         test_op_stats = None
-        for op_stats in profile.op_stats:
+        for op_stats in signal.op_stats:
             if op_stats.op_name == 'RandomUniform':
                 test_op_stats = op_stats
                 break
@@ -78,4 +78,4 @@ class TensorflowProfilerTest(unittest.TestCase):
             self.assertTrue(test_op_stats.total_host_time_us >= 1)
             self.assertTrue(test_op_stats.self_host_time_us >= 1)
 
-        self.assertNotEqual(profile.trace_data, b'')
+        self.assertNotEqual(signal.trace_data, b'')
