@@ -14,31 +14,31 @@ from urllib.error import URLError
 from urllib.error import HTTPError
 
 import graphsignal
-from graphsignal.proto import profiles_pb2
+from graphsignal.proto import signals_pb2
 
 logger = logging.getLogger('graphsignal')
 
 
 class Uploader:
-    MAX_BUFFER_SIZE = 2500
+    MAX_BUFFER_SIZE = 25
 
     def __init__(self):
-        self.profile_api_url = 'https://profile-api.graphsignal.com'
+        self.agent_api_url = 'https://agent-api.graphsignal.com'
         self.buffer = []
         self.buffer_lock = threading.Lock()
         self.flush_lock = threading.Lock()
 
-    def configure(self):
-        if 'GRAPHSIGNAL_PROFILE_API_URL' in os.environ:
-            self.profile_api_url = os.environ['GRAPHSIGNAL_PROFILE_API_URL']
+    def setup(self):
+        if 'GRAPHSIGNAL_AGENT_API_URL' in os.environ:
+            self.agent_api_url = os.environ['GRAPHSIGNAL_AGENT_API_URL']
 
     def clear(self):
         with self.buffer_lock:
             self.buffer = []
 
-    def upload_profile(self, profile):
+    def upload_signal(self, signal):
         with self.buffer_lock:
-            self.buffer.append(profile)
+            self.buffer.append(signal)
             if len(self.buffer) > self.MAX_BUFFER_SIZE:
                 self.buffer = self.buffer[-self.MAX_BUFFER_SIZE:]
 
@@ -54,27 +54,21 @@ class Uploader:
                 self.buffer = []
             try:
                 upload_start = time.time()
-                upload_request = profiles_pb2.UploadRequest()
-                upload_request.ml_profiles.extend(outgoing)
-                upload_request.upload_ms = int(time.time() * 1e3)
-                payload = upload_request.SerializeToString()
-                resp = self._post('profiles', payload)
-                upload_response = profiles_pb2.UploadResponse()
-                upload_response.ParseFromString(resp)
+                payload = _create_upload_request(outgoing)
+                content = self._post('signals', payload)
+                _create_upload_response(content)
                 logger.debug('Upload took %.3f sec (%dB)', time.time() - upload_start, len(payload))
             except URLError:
-                logger.debug('Failed uploading profiles, will retry', exc_info=True)
+                logger.debug('Failed uploading signals, will retry', exc_info=True)
                 with self.buffer_lock:
                     self.buffer[:0] = outgoing
             except Exception:
-                logger.error('Error uploading profiles', exc_info=True)
+                logger.error('Error uploading signals', exc_info=True)
 
     def _post(self, endpoint, data):
-        logger.debug('Posting data to %s/%s',
-                     self.profile_api_url, endpoint)
+        logger.debug('Posting data to %s/%s', self.agent_api_url, endpoint)
 
-        api_key_64 = _base64_encode(
-            graphsignal._agent.api_key + ':').replace('\n', '')
+        api_key_64 = _base64_encode(graphsignal._agent.api_key + ':').replace('\n', '')
         headers = {
             'Accept-Encoding': 'gzip',
             'Authorization': "Basic %s" % api_key_64,
@@ -82,36 +76,59 @@ class Uploader:
             'Content-Encoding': 'gzip'
         }
 
-        gzip_out = BytesIO()
-        with gzip.GzipFile(fileobj=gzip_out, mode="w") as out_file:
-            out_file.write(data)
-            out_file.close()
+        data_gzip = _gzip_data(data)
 
-        gzip_out_val = gzip_out.getvalue()
-        if isinstance(gzip_out_val, str):
-            data_gzip = bytearray(gzip_out.getvalue())
-        else:
-            data_gzip = gzip_out.getvalue()
         request = Request(
-            url=self.profile_api_url + '/' + endpoint,
+            url=self.agent_api_url + '/' + endpoint,
             data=data_gzip,
             headers=headers)
 
         try:
             resp = urlopen(request, timeout=10)
-            result_data = resp.read()
+            content = resp.read()
             if resp.info():
                 content_type = resp.info().get('Content-Encoding')
                 if content_type == 'gzip':
-                    result_data = gzip.GzipFile(
-                        '', 'r', 0, BytesIO(result_data)).read()
+                    content = _gunzip_data(content)
             resp.close()
-            return result_data
+            return content
         except HTTPError as herr:
             logger.debug('Error message from server: %s',
                          herr.read().decode('utf-8'))
             raise herr
 
 
+def _create_upload_request(outgoing):
+    upload_request = signals_pb2.UploadRequest()
+    upload_request.ml_signals.extend(outgoing)
+    upload_request.upload_ms = int(time.time() * 1e3)
+    return upload_request.SerializeToString()
+
+
+def _create_upload_response(content):
+    upload_response = signals_pb2.UploadResponse()
+    upload_response.ParseFromString(content)
+    return upload_response
+
+
+def _gzip_data(data):
+    gzip_out = BytesIO()
+    with gzip.GzipFile(fileobj=gzip_out, mode="w") as out_file:
+        out_file.write(data)
+        out_file.close()
+
+    gzip_out_val = gzip_out.getvalue()
+    if isinstance(gzip_out_val, str):
+        data_gzip = bytearray(gzip_out.getvalue())
+    else:
+        data_gzip = gzip_out.getvalue()
+
+    return data_gzip
+
+
+def _gunzip_data(data):
+    return gzip.GzipFile('', 'r', 0, BytesIO(data)).read()
+
+
 def _base64_encode(s):
     return base64.b64encode(s.encode('utf-8')).decode('utf-8')
